/**
 * 
 */
package com.github.ansell.oas.objects.test;

import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.openrdf.model.Literal;
import org.openrdf.model.URI;
import org.openrdf.model.ValueFactory;
import org.openrdf.sail.memory.model.MemValueFactory;

import com.github.ansell.oas.objects.Annotation;

/**
 * Tests the interface for the simple annotations that we are using in the ontology annotation
 * service.
 * 
 * @author Peter Ansell p_ansell@yahoo.com
 */
public abstract class AbstractAnnotationTest
{
    private Annotation testAnnotation;
    private URI testAnnotatedObjectUri;
    private URI testAnnotatedObjectType;
    private URI testOntologyUri;
    private URI testAnnotator;
    private Literal testTag;
    
    /**
     * 
     * @return A new empty instance of Annotation for each invocation of this method.
     */
    public abstract Annotation getNewTestAnnotation();
    
    /**
     * Setup method which is run before each test.
     * 
     * @throws java.lang.Exception
     */
    @Before
    public void setUp() throws Exception
    {
        this.testAnnotation = this.getNewTestAnnotation();
        
        final ValueFactory f = new MemValueFactory();
        
        this.testAnnotatedObjectUri = f.createURI("http://example.org/test/annotationobjecturi");
        this.testAnnotatedObjectType = f.createURI("http://example.org/test/annotationobjecttype");
        this.testOntologyUri = f.createURI("http://example.org/test/ontologyuri");
        this.testAnnotator = f.createURI("http://example.org/test/annotator");
        this.testTag = f.createLiteral("test tag");
    }
    
    /**
     * Cleanup method which is run after each test.
     * 
     * @throws java.lang.Exception
     */
    @After
    public void tearDown() throws Exception
    {
        this.testAnnotation = null;
        
        this.testAnnotatedObjectUri = null;
        this.testAnnotatedObjectType = null;
        this.testOntologyUri = null;
        this.testAnnotator = null;
        this.testTag = null;
    }
    
    /**
     * Test method for {@link com.github.ansell.oas.objects.Annotation#getAnnotatedObjectType()} .
     */
    @Test
    public void testGetAnnotatedObjectType()
    {
        Assert.assertNull(this.testAnnotation.getAnnotatedObjectType());
    }
    
    /**
     * Test method for {@link com.github.ansell.oas.objects.Annotation#getAnnotatedObjectUri()} .
     */
    @Test
    public void testGetAnnotatedObjectUri()
    {
        Assert.assertNull(this.testAnnotation.getAnnotatedObjectUri());
    }
    
    /**
     * Test method for {@link com.github.ansell.oas.objects.Annotation#getAnnotator()} .
     */
    @Test
    public void testGetAnnotator()
    {
        Assert.assertNull(this.testAnnotation.getAnnotator());
    }
    
    /**
     * Test method for {@link com.github.ansell.oas.objects.Annotation#getOntologyTermUri()} .
     */
    @Test
    public void testGetOntologyUri()
    {
        Assert.assertNull(this.testAnnotation.getOntologyTermUri());
    }
    
    /**
     * Test method for {@link com.github.ansell.oas.objects.Annotation#getTag()} .
     */
    @Test
    public void testGetTag()
    {
        Assert.assertNull(this.testAnnotation.getTag());
    }
    
    /**
     * Test method for
     * {@link com.github.ansell.oas.objects.Annotation#setAnnotatedObjectType(org.openrdf.model.URI)}
     * .
     */
    @Test
    public void testSetAnnotatedObjectType()
    {
        Assert.assertNull(this.testAnnotation.getAnnotatedObjectType());
        
        this.testAnnotation.setAnnotatedObjectType(this.testAnnotatedObjectType);
        
        Assert.assertNotNull(this.testAnnotation.getAnnotatedObjectType());
        
        Assert.assertEquals(this.testAnnotation.getAnnotatedObjectType(), this.testAnnotatedObjectType);
    }
    
    /**
     * Test method for
     * {@link com.github.ansell.oas.objects.Annotation#setAnnotatedObjectUri(org.openrdf.model.URI)}
     * .
     */
    @Test
    public void testSetAnnotatedObjectUri()
    {
        Assert.assertNull(this.testAnnotation.getAnnotatedObjectUri());
        
        this.testAnnotation.setAnnotatedObjectUri(this.testAnnotatedObjectUri);
        
        Assert.assertNotNull(this.testAnnotation.getAnnotatedObjectUri());
        
        Assert.assertEquals(this.testAnnotation.getAnnotatedObjectUri(), this.testAnnotatedObjectUri);
    }
    
    /**
     * Test method for
     * {@link com.github.ansell.oas.objects.Annotation#setAnnotator(org.openrdf.model.URI)} .
     */
    @Test
    public void testSetAnnotator()
    {
        Assert.assertNull(this.testAnnotation.getAnnotator());
        
        this.testAnnotation.setAnnotator(this.testAnnotator);
        
        Assert.assertNotNull(this.testAnnotation.getAnnotator());
        
        Assert.assertEquals(this.testAnnotation.getAnnotator(), this.testAnnotator);
    }
    
    /**
     * Test method for
     * {@link com.github.ansell.oas.objects.Annotation#setOntologyTermUri(org.openrdf.model.URI)} .
     */
    @Test
    public void testSetOntologyUri()
    {
        Assert.assertNull(this.testAnnotation.getOntologyTermUri());
        
        this.testAnnotation.setOntologyTermUri(this.testOntologyUri);
        
        Assert.assertNotNull(this.testAnnotation.getOntologyTermUri());
        
        Assert.assertEquals(this.testAnnotation.getOntologyTermUri(), this.testOntologyUri);
    }
    
    /**
     * Test method for
     * {@link com.github.ansell.oas.objects.Annotation#setTag(org.openrdf.model.Literal)} .
     */
    @Test
    public void testSetTag()
    {
        Assert.assertNull(this.testAnnotation.getTag());
        
        this.testAnnotation.setTag(this.testTag);
        
        Assert.assertNotNull(this.testAnnotation.getTag());
        
        Assert.assertEquals(this.testAnnotation.getTag(), this.testTag);
    }
}
