/**
 * 
 */
package com.github.ansell.oas.objects.test;

import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import com.github.ansell.oas.objects.ResourceCount;

/**
 * Tests the interface for the resource counts that we are using in the ontology annotation service.
 * 
 * @author Peter Ansell p_ansell@yahoo.com
 */
public abstract class AbstractResourceCountTest
{
    private ResourceCount testResourceCount;
    
    /**
     * Each implementing non-abstract test needs to return a new instance of their implementation of
     * the ResourceCount interface.
     * 
     * @return A new empty instance of ResourceCount for each invocation of this method.
     */
    public abstract ResourceCount getNewTestResourceCount();
    
    /**
     * Setup method which is run before each test.
     * 
     * @throws java.lang.Exception
     */
    @Before
    public void setUp() throws Exception
    {
        this.testResourceCount = this.getNewTestResourceCount();
    }
    
    /**
     * Cleanup method which is run after each test.
     * 
     * @throws java.lang.Exception
     */
    @After
    public void tearDown() throws Exception
    {
        this.testResourceCount = null;
    }
    
    /**
     * Test method for {@link com.github.ansell.oas.objects.ResourceCount#getCount()} .
     */
    @Test
    public void testGetCount()
    {
        Assert.assertEquals(0, this.testResourceCount.getCount());
        
        this.testResourceCount.setCount(12344);
        
        Assert.assertEquals(12344, this.testResourceCount.getCount());
    }
    
    /**
     * Test method for {@link com.github.ansell.oas.objects.ResourceCount#setCount(int)} .
     */
    @Test
    public void testSetCount()
    {
        this.testResourceCount.setCount(42);
        
        Assert.assertEquals(42, this.testResourceCount.getCount());
    }
}
