/**
 * 
 */
package com.github.ansell.oas.test;

import org.junit.Assert;
import org.openrdf.model.Model;

import com.github.ansell.oas.objects.Annotation;

/**
 * Test utility for the abstract test classes.
 * 
 * @author Peter Ansell p_ansell@yahoo.com
 */
public class AbstractTestUtils
{
    public static void assertModel(final Model model, final int expectedSize, final int expectedSubjects,
            final int expectedPredicates, final int expectedObjects) throws Exception
    {
        Assert.assertNotNull("Model was null", model);
        Assert.assertEquals("Model size was not as expected", expectedSize, model.size());
        Assert.assertEquals("Number of subjects in model was not as expected", expectedSubjects, model.subjects()
                .size());
        Assert.assertEquals("Number of predicates in model was not as expected", expectedPredicates, model.predicates()
                .size());
        Assert.assertEquals("Number of objects in model was not as expected", expectedObjects, model.objects().size());
    }
    
    public static void testAnnotationsMatch(final Annotation sourceAnnotation, final Annotation matchingAnnotation)
    {
        Assert.assertNotNull(sourceAnnotation);
        Assert.assertNotNull(matchingAnnotation);
        Assert.assertEquals(sourceAnnotation.getAnnotationUniqueId(), matchingAnnotation.getAnnotationUniqueId());
        Assert.assertEquals(sourceAnnotation.getAnnotatedObjectUri(), matchingAnnotation.getAnnotatedObjectUri());
        Assert.assertEquals(sourceAnnotation.getAnnotatedObjectType(), matchingAnnotation.getAnnotatedObjectType());
        Assert.assertEquals(sourceAnnotation.getAnnotator(), matchingAnnotation.getAnnotator());
        Assert.assertEquals(sourceAnnotation.getOntologyTermUri(), matchingAnnotation.getOntologyTermUri());
        Assert.assertEquals(sourceAnnotation.getTag(), matchingAnnotation.getTag());
    }
}
